Package: scDDboost
Type: Package
Title: A compositional model to assess expression changes from
        single-cell rna-seq data
Version: 1.13.0
Date: 2018-10-31
Authors@R: c(person("Xiuyu","Ma",email="watsonforfun@gmail.com",role = c("cre", "aut")),person(given = "Michael A.",family = "Newton", email="newton@stat.wisc.edu",role = "ctb"))
Description: scDDboost is an R package to analyze changes in the distribution of single-cell expression data between two experimental conditions. Compared to other methods that assess differential expression, scDDboost benefits uniquely from information conveyed by the clustering of cells into cellular subtypes. Through a novel empirical Bayesian formulation it calculates gene-specific posterior probabilities that the marginal expression distribution is the same (or different) between the two conditions. The implementation in scDDboost treats gene-level expression data within each condition as a mixture of negative binomial distributions.
License: GPL (>= 2)
Imports: Rcpp (>= 0.12.11), RcppEigen (>= 0.3.2.9.0),EBSeq,
        BiocParallel, mclust, SingleCellExperiment, cluster, Oscope,
        SummarizedExperiment, stats, methods
biocViews: SingleCell, Software, Clustering, Sequencing,
        GeneExpression, DifferentialExpression, Bayesian
Depends: R (>= 4.2), ggplot2
LinkingTo: Rcpp, RcppEigen, BH
Suggests: knitr, rmarkdown, BiocStyle, testthat
SystemRequirements: c++14
Roxygen: list(wrap=FALSE)
RoxygenNote: 7.1.2
VignetteBuilder: knitr
BugReports: https://github.com/wiscstatman/scDDboost/issues
URL: https://github.com/wiscstatman/scDDboost
git_url: https://git.bioconductor.org/packages/scDDboost
git_branch: devel
git_last_commit: 009edb1
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-03
NeedsCompilation: yes
Packaged: 2025-11-04 00:43:06 UTC; biocbuild
Author: Xiuyu Ma [cre, aut],
  Michael A. Newton [ctb]
Maintainer: Xiuyu Ma <watsonforfun@gmail.com>
