useDynLib(scDDboost)
import(RcppEigen)
importFrom(BiocParallel,MulticoreParam,bplapply)
importFrom(SingleCellExperiment,colData)
importFrom(ggplot2,ggplot,geom_bar,facet_grid,coord_polar,xlab,ylab,theme,element_rect,element_line,geom_violin,geom_jitter)
importFrom(mclust,adjustedRandIndex)
importFrom(Oscope,CalcMV)
importFrom(cluster, pam)
importFrom(EBSeq,MedianNorm)
importFrom(Rcpp, evalCpp)
importFrom(stats,dist,cor,sd,nlminb,rgamma)
importFrom(SummarizedExperiment,assays)
importFrom("methods", "is")
export(pdd,calD,detK,getDD,getSizeofDD,pat,extractInfo)