#' scDDboost
#'
#' simulated data for demonstration, data are mixture negative binomial distributed
#'
#' @docType data
#'
#' @usage data(sim_dat)
#'
#' @format An object of class \code{"list"}.
#'
#' @keywords datasets
#'

#' @examples
#' data(sim_dat)
"sim_dat"
