% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pat.R
\name{pat}
\alias{pat}
\title{generating partition patterns}
\usage{
pat(K)
}
\arguments{
\item{K}{number of elements}
}
\value{
all possible partition of K elements
}
\description{
generating partition patterns
}
\examples{
pat(3)
}
