% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pddRandom.R
\name{pddRandom}
\alias{pddRandom}
\title{calculate PDD when add random noise in distance matrix}
\usage{
pddRandom(data, cd, K, D, a, sz, hp, Posp, iter, REF, stp1, stp2)
}
\arguments{
\item{data}{normalized preprocessed transcripts}

\item{cd}{condition label}

\item{K}{number of subgroups}

\item{D}{distance matrix of cells}

\item{a}{shape param for weights}

\item{sz}{size factors}

\item{hp}{hyper parameters for EBSeq}

\item{Posp}{parition patterns}

\item{iter}{max number of iterations for EM in EBSeq}

\item{REF}{refinement relation matrix}

\item{stp1}{step size of hyperparameter alpha (shared by all units) in one step EM}

\item{stp2}{step size of hyperparameter beta (unit specific) in one step EM}
}
\value{
posterior probabilities under random distance matrix
}
\description{
calculate PDD when add random noise in distance matrix
}
\keyword{internal}
